`Pyramid_Modern <http://www.github.com/KamiQuasi/pyramid_modern>`_
==================================================================

This project is a scaffold for the Pyramid web framework 
seeking to incorporate modern front-end
projects into the default starter scaffold.

Major Integrations
------------------------

* `HTML5 Boilerplate <https://github.com/h5bp/html5-boilerplate>`_
* `Modernizr <http://www.modernizr.com/>`_ (`LICENSE`__) 
* `Twitter Bootstrap <http://twitter.github.com/bootstrap/>`_ (`LICENSE`__)
* `RequireJS <http://requirejs.org>`_ (`LICENSE`__) 
* `Backbone.js <http://backbonejs.org/>`_ (`LICENSE`__)
* `Underscore.js <http://documentcloud.github.com/underscore/>`_ (`LICENSE`__)
* `Handlebars.js <http://handlebarsjs.com/>`_ (`LICENSE`__) 
* `jQuery <http://jquery.com/>`_ (`LICENSE`__)

__ http://www.modernizr.com/license/
__ http://www.apache.org/licenses/LICENSE-2.0
__ https://github.com/jrburke/requirejs/blob/master/LICENSE
__ https://github.com/documentcloud/backbone/blob/master/LICENSE
__ https://github.com/documentcloud/underscore/blob/master/LICENSE
__ https://github.com/wycats/handlebars.js/blob/master/LICENSE
__ http://jquery.org/license/
